View source: R/Cal_cor_pleiotropic_h2.R
| Cal_cor_pleiotropic_h2 | R Documentation |
Compute a vector of pleioh2g for all diseases before correction This function computes pleioh2g for all diseases before correction in one go.
Cal_cor_pleiotropic_h2(rg_mat, h2g_T)
rg_mat |
genetic correlation matrix. |
h2g_T |
heritability vector for all diseases. |
pleioh2g vector
data(Results_full_rg)
data(h2_vector)
Cal_cor_pleiotropic_h2(Results_full_rg,h2_vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.