Cal_cor_pleiotropic_h2_corrected_single: Compute single pleioh2g for target disease after correction...

View source: R/Cal_cor_pleiotropic_h2_corrected_single.R

Cal_cor_pleiotropic_h2_corrected_singleR Documentation

Compute single pleioh2g for target disease after correction with referred disease index in the rg matrix and corrected ratio

Description

This function computes pleioh2g for the target disease after correction.

Usage

Cal_cor_pleiotropic_h2_corrected_single(
  rg_mat,
  h2g_T_single,
  corrected_weight_updated,
  plei_h2_idx
)

Arguments

rg_mat

genetic correlation matrix.

h2g_T_single

heritability for target diseases.

corrected_weight_updated

the ratio for correction

plei_h2_idx

index of the target disease in the rg_mat.

Value

pleioh2g value for the target disease after correction

Examples


data(Results_full_rg)
data(h2_vector)
plei_h2_idx<-1
h2g_T_single <- h2_vector[plei_h2_idx]
corrected_weight_updated <- 0.78
Cal_cor_pleiotropic_h2_corrected_single(Results_full_rg,h2g_T_single,
corrected_weight_updated,plei_h2_idx)

pleioh2g documentation built on March 9, 2026, 5:07 p.m.