Cal_cor_test_single: Compute inversed elements for the target disease in bias...

View source: R/Cal_cor_test_single.R

Cal_cor_test_singleR Documentation

Compute inversed elements for the target disease in bias correction procedure with referred disease index in the rg matrix

Description

This function inversed elements for the target disease in bias correction procedure.

Usage

Cal_cor_test_single(rg_mat, plei_h2_idx)

Arguments

rg_mat

genetic correlation matrix.

plei_h2_idx

index of the target disease in the rg_mat.

Value

inverse element value for the target disease used for bias correction

Examples

data(Results_full_rg)
plei_h2_idx<-1
Cal_cor_test_single(Results_full_rg,plei_h2_idx)

pleioh2g documentation built on March 9, 2026, 5:07 p.m.