View source: R/generate_proposal_sample_changea_cor.R
| generate_proposal_sample_changea_cor | R Documentation |
This function is used to generate samples based on sampling covariance matrix and rg matrix for target disease
generate_proposal_sample_changea_cor(
Results_full_rg,
Results_full_rg_array,
plei_h2_idx,
ratio_a
)
Results_full_rg |
genetic correlation matrix. |
Results_full_rg_array |
genetic correlation jackknife-block array. |
plei_h2_idx |
index of the target disease in the rg_mat. |
ratio_a |
corrected ratio. |
noisy_inversed_element for bias correction
data(Results_full_rg)
data(Results_full_rg_array)
Results_full_rg<-Results_full_rg[1:15,1:15]
Results_full_rg_array<-Results_full_rg_array[1:15,1:15,]
plei_h2_idx<-1
ratio_a <- 0.75
generate_proposal_sample_changea_cor(Results_full_rg,
Results_full_rg_array, plei_h2_idx, ratio_a)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.