read_m: Read M from either internal or external file - refer to ldscr...

View source: R/read_m.R

read_mR Documentation

Read M from either internal or external file - refer to ldscr R package (https://github.com/mglev1n/ldscr)

Description

'read_m()' Read M from either internal or external file

Usage

read_m(ld)

Arguments

ld

(character) Path to directory containing ld score files, ending in '*.l2.ldscore.gz'.

Value

A data frame (tibble) containing SNP counts read from the specified M files.


pleioh2g documentation built on March 9, 2026, 5:07 p.m.