read_wld: Read wld from either internal or external file - refer to...

View source: R/read_wld.R

read_wldR Documentation

Read wld from either internal or external file - refer to ldscr R package (https://github.com/mglev1n/ldscr)

Description

'read_wld()' Read wld from either internal or external file

Usage

read_wld(wld)

Arguments

wld

(character) Path to directory containing weight files. Default is 'NA', which will utilize the built-in weight files from Pan-UK Biobank for the ancestry specified in 'ancestry'.

Value

A data frame (tibble) containing LD weight information read from the specified directory. Each row corresponds to a SNP, and columns typically include:

  • CHR: Chromosome number.

  • SNP: SNP identifier (rsID).

  • BP: Base pair position.

  • wLD: Weight for LD regression.


pleioh2g documentation built on March 9, 2026, 5:07 p.m.