Learn R Programming

pleioh2g (version 0.1.1)

Cal_cor_pleiotropic_h2: Compute a vector of pleioh2g for all diseases before correction This function computes pleioh2g for all diseases before correction in one go.

Description

Compute a vector of pleioh2g for all diseases before correction This function computes pleioh2g for all diseases before correction in one go.

Usage

Cal_cor_pleiotropic_h2(rg_mat, h2g_T)

Value

pleioh2g vector

Arguments

rg_mat

genetic correlation matrix.

h2g_T

heritability vector for all diseases.

Examples

Run this code
data(Results_full_rg)
data(h2_vector)
Cal_cor_pleiotropic_h2(Results_full_rg,h2_vector)

Run the code above in your browser using DataLab