View source: R/Cal_cor_test_single.R
| Cal_cor_test_single | R Documentation |
This function inversed elements for the target disease in bias correction procedure.
Cal_cor_test_single(rg_mat, plei_h2_idx)
rg_mat |
genetic correlation matrix. |
plei_h2_idx |
index of the target disease in the rg_mat. |
inverse element value for the target disease used for bias correction
data(Results_full_rg)
plei_h2_idx<-1
Cal_cor_test_single(Results_full_rg,plei_h2_idx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.