powered by
This function is used to generate samples based on sampling covariance matrix and rg matrix for target disease
generate_proposal_sample_changea_cor( Results_full_rg, Results_full_rg_array, plei_h2_idx, ratio_a )
noisy_inversed_element for bias correction
genetic correlation matrix.
genetic correlation jackknife-block array.
index of the target disease in the rg_mat.
corrected ratio.
data(Results_full_rg_15D) data(Results_full_rg_array_15D) plei_h2_idx<-1 ratio_a <- 0.75 generate_proposal_sample_changea_cor(Results_full_rg_15D, Results_full_rg_array_15D, plei_h2_idx, ratio_a)
Run the code above in your browser using DataLab