Learn R Programming

pleioh2g (version 0.1.1)

read_m: Read M from either internal or external file - refer to ldscr R package (https://github.com/mglev1n/ldscr)

Description

`read_m()` Read M from either internal or external file

Usage

read_m(ld)

Value

A data frame (tibble) containing SNP counts read from the specified M files.

Arguments

ld

(character) Path to directory containing ld score files, ending in `*.l2.ldscore.gz`.